@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ public slots:
 	//! Generic open, with autodetection of type
 	void open(QString file, int seek=-1); 
 	void openFile(QString filename, int seek=-1);
-	void openStream(QString name);
+	void openStream(QString name, QStringList params = QStringList());
 	/*
 	void openDVD( bool from_folder, QString directory = "");
 	void openDVD(); // Plays title 1
@@ -254,6 +254,10 @@ public slots:
 	void incOSDScale();
 	void decOSDScale();
 
+#ifdef MPV_SUPPORT
+	void setOSDFractions(bool active);
+#endif
+
 	//! Select next line in subtitle file
 	void incSubStep();
 	//! Select previous line in subtitle file
@@ -308,6 +312,8 @@ public slots:
 #ifdef BOOKMARKS
 	void nextBookmark();
 	void prevBookmark();
+
+	void saveBookmarks();
 #endif
 
 	#if 0
@@ -498,6 +504,7 @@ signals:
 	void newDuration(double); // Duration has changed
 	void showFrame(int frame);
 	void ABMarkersChanged(int secs_a, int secs_b);
+	void bitrateChanged(int vbitrate, int abitrate);
 	void needResize(int w, int h);
 	void noVideo();
 	void volumeChanged(int);
