@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -89,10 +89,10 @@ void MediaSettings::reset() {
 	//current_deinterlacer = NoDeinterlace;
 	current_deinterlacer = pref->initial_deinterlace;
 
-#ifdef ADD_BLACKBORDERS_FS
-	add_letterbox = false;
-#else
+#ifdef INITIAL_BLACKBORDERS
 	add_letterbox = pref->initial_blackborders;
+#else
+	add_letterbox = false;
 #endif
 
 #ifdef MPLAYER_SUPPORT
