@@ -64,6 +64,10 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 			"INFO_MEDIA_TITLE=${=media-title:}\n"
 			"INFO_STREAM_PATH=${stream-path}\n";
 
+#ifndef Q_OS_WIN
+	arg << "--audio-client-name=SMPlayer";
+#endif
+
 #ifdef CUSTOM_STATUS
 	arg << "--term-status-msg=STATUS: ${=time-pos} / ${=duration:${=length:0}} P: ${=pause} B: ${=paused-for-cache} I: ${=core-idle} VB: ${=video-bitrate:0} AB: ${=audio-bitrate:0}";
 #endif
@@ -185,9 +189,11 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	}
 	else
 	if (option_name == "loop") {
+		QString loop = "--loop";
+		if (isOptionAvailable("--loop-file")) loop = "--loop-file";
 		QString o = value.toString();
 		if (o == "0") o = "inf";
-		arg << "--loop=" + o;
+		arg << loop + "=" + o;
 	}
 	else
 	if (option_name == "ass") {
@@ -352,6 +358,13 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 			}
 		}
 		#endif
+
+		// Remove options (used by mplayer)
+		int pos = vo.indexOf(":");
+		if (pos > -1) vo = vo.left(pos);
+
+		if (vo == "gl") vo = "opengl";
+
 		arg << "--vo=" + vo + ",";
 	}
 	else
@@ -397,6 +410,11 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 			}
 			#endif
 		}
+
+		// Remove options (used by mplayer)
+		int pos = ao.indexOf(":");
+		if (pos > -1) ao = ao.left(pos);
+
 		arg << "--ao=" + ao + ",";
 	}
 	else
@@ -614,9 +632,9 @@ void MPVProcess::addAF(const QString & filter_name, const QVariant & value) {
 	QString option = value.toString();
 
 	if (filter_name == "volnorm") {
-		QString s = "drc";
+		QString s = "acompressor";
 		if (!option.isEmpty()) s += "=" + option;
-		arg << "--af-add=" + s;
+		arg << "--af-add=lavfi=[" + s + "]";
 	}
 	else
 	if (filter_name == "channels") {
@@ -864,7 +882,9 @@ void MPVProcess::enableExtrastereo(bool b) {
 }
 
 void MPVProcess::enableVolnorm(bool b, const QString & option) {
-	if (b) writeToStdin("af add drc=" + option); else writeToStdin("af del drc=" + option);
+	QString s = "acompressor";
+	if (!option.isEmpty()) s += "=" + option;
+	if (b) writeToStdin("af add lavfi=[" + s + "]"); else writeToStdin("af del lavfi=[" + s + "]");
 }
 
 void MPVProcess::setAudioEqualizer(const QString & values) {
@@ -892,7 +912,7 @@ void MPVProcess::setLoop(int v) {
 		case 0: o = "inf"; break;
 		default: o = QString::number(v);
 	}
-	writeToStdin(QString("set loop %1").arg(o));
+	writeToStdin(QString("set loop-file %1").arg(o));
 }
 
 void MPVProcess::setAMarker(int sec) {
@@ -979,6 +999,10 @@ void MPVProcess::setOSDScale(double value) {
 	writeToStdin("set osd-scale " + QString::number(value));
 }
 
+void MPVProcess::setOSDFractions(bool active) {
+	writeToStdin(QString("no-osd set osd-fractions %1").arg(active ? "yes" : "no"));
+}
+
 void MPVProcess::changeVF(const QString & filter, bool enable, const QVariant & option) {
 	qDebug() << "MPVProcess::changeVF:" << filter << enable;
 
