@@ -72,6 +72,8 @@ MPVProcess::MPVProcess(QObject * parent)
              this, SLOT(gotError(QProcess::ProcessError)) );
 
 	/* int svn = MplayerVersion::mplayerVersion("mpv unknown version (C)"); */
+
+	initializeRX();
 }
 
 MPVProcess::~MPVProcess() {
@@ -114,55 +116,51 @@ bool MPVProcess::start() {
 	return waitForStarted();
 }
 
+void MPVProcess::initializeRX() {
 #ifdef CUSTOM_STATUS
-static QRegExp rx_mpv_av("^STATUS: ([0-9\\.-]+) / ([0-9\\.-]+) P: (yes|no) B: (yes|no) I: (yes|no) VB: ([0-9\\.-]+) AB: ([0-9\\.-]+)");
+	rx_av.setPattern("^STATUS: ([0-9\\.-]+) / ([0-9\\.-]+) P: (yes|no) B: (yes|no) I: (yes|no) VB: ([0-9\\.-]+) AB: ([0-9\\.-]+)");
 #else
-static QRegExp rx_mpv_av("^(\\((.*)\\) |)(AV|V|A): ([0-9]+):([0-9]+):([0-9]+) / ([0-9]+):([0-9]+):([0-9]+)"); //AV: 00:02:15 / 00:09:56
+	rx_av.setPattern("^(\\((.*)\\) |)(AV|V|A): ([0-9]+):([0-9]+):([0-9]+) / ([0-9]+):([0-9]+):([0-9]+)"); //AV: 00:02:15 / 00:09:56
 #endif
 
-static QRegExp rx_mpv_dsize("^INFO_VIDEO_DSIZE=(\\d+)x(\\d+)");
-static QRegExp rx_mpv_vo("^VO: \\[(.*)\\]");
-static QRegExp rx_mpv_ao("^AO: \\[(.*)\\]");
-static QRegExp rx_mpv_paused("^\\(Paused\\)");
-static QRegExp rx_mpv_endoffile("^Exiting... \\(End of file\\)");
+	rx_dsize.setPattern("^INFO_VIDEO_DSIZE=(\\d+)x(\\d+)");
+	rx_vo.setPattern("^VO: \\[(.*)\\]");
+	rx_ao.setPattern("^AO: \\[(.*)\\]");
+	rx_paused.setPattern("^\\(Paused\\)");
+	rx_endoffile.setPattern("^Exiting... \\(End of file\\)");
+
+	rx_audio.setPattern("^.* Audio\\s+--aid=(\\d+)( --alang=([a-zA-Z-]+)|)([ \\(\\)\\*]+)('(.*)'|)");
+	rx_subs.setPattern("^.* Subs\\s+--sid=(\\d+)( --slang=([a-zA-Z-]+)|)([ \\(\\)\\*]+)('(.*)'|)");
+
+	rx_videocodec.setPattern("^INFO_VIDEO_CODEC=(.*)\\s");
+	rx_videocodec.setMinimal(true);
+
+	rx_audiocodec.setPattern("^INFO_AUDIO_CODEC=(.*)\\s");
+	rx_audiocodec.setMinimal(true);
 
-//static QRegExp rx_mpv_audio("^\\[stream\\] Audio .* --aid=(\\d+)( --alang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
-static QRegExp rx_mpv_audio("^.* Audio\\s+--aid=(\\d+)( --alang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
-//static QRegExp rx_mpv_subs("^\\[stream\\] Subs .* --sid=(\\d+)( --slang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
-static QRegExp rx_mpv_subs("^.* Subs\\s+--sid=(\\d+)( --slang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
 #if !NOTIFY_VIDEO_CHANGES
-//static QRegExp rx_mpv_video("^\\[stream\\] Video .* --vid=(\\d+)([ \\(\\)\\*]+)('(.*)'|)");
-static QRegExp rx_mpv_video("^.* Video\\s+--vid=(\\d+)([ \\(\\)\\*]+)('(.*)'|)");
+	rx_video.setPattern("^.* Video\\s+--vid=(\\d+)([ \\(\\)\\*]+)('(.*)'|)");
 #endif
 
-#if 0
-static QRegExp rx_mpv_subs2("^Sub:( >|) \\((\\d+)\\) '(.*)'");
-#endif
+	rx_chaptername.setPattern("^INFO_CHAPTER_(\\d+)_NAME=(.*)");
+	rx_trackinfo.setPattern("^INFO_TRACK_(\\d+): (audio|video|sub) (\\d+) '(.*)' '(.*)' (yes|no)");
 
-static QRegExp rx_mpv_chaptername("^INFO_CHAPTER_(\\d+)_NAME=(.*)");
-static QRegExp rx_mpv_trackinfo("^INFO_TRACK_(\\d+): (audio|video|sub) (\\d+) '(.*)' '(.*)' (yes|no)");
-
-#if 0
-static QRegExp rx_mpv_videoinfo("^\\[vd\\] VIDEO: .* (\\d+)x(\\d+) .* ([0-9.]+) fps"); // [vd] VIDEO:  624x352  25.000 fps  1018.5 kbps (127.3 kB/s)
-#endif
-
-static QRegExp rx_mpv_videocodec("^INFO_VIDEO_CODEC=(.*) \\[(.*)\\]");
-static QRegExp rx_mpv_audiocodec("^INFO_AUDIO_CODEC=(.*) \\[(.*)\\]");
-
-static QRegExp rx_mpv_forbidden("HTTP error 403 Forbidden");
+	rx_forbidden.setPattern("HTTP error 403 Forbidden");
 
 #if DVDNAV_SUPPORT
-static QRegExp rx_mpv_switch_title("^\\[dvdnav\\] DVDNAV, switched to title: (\\d+)");
+	rx_switch_title.setPattern("^\\[dvdnav\\] DVDNAV, switched to title: (\\d+)");
 #endif
 
-static QRegExp rx_mpv_playing("^Playing:.*|^\\[ytdl_hook\\].*");
+	rx_playing.setPattern("^Playing:.*|^\\[ytdl_hook\\].*");
+	rx_generic.setPattern("^([A-Z_]+)=(.*)");
+	rx_stream_title.setPattern("icy-title: (.*)");
+	rx_debug.setPattern("^(INFO|METADATA)_.*=\\$.*");
 
-//static QRegExp rx_mpv_generic("^(.*)=(.*)");
-static QRegExp rx_mpv_generic("^([A-Z_]+)=(.*)");
-
-static QRegExp rx_mpv_stream_title("icy-title: (.*)");
-
-static QRegExp rx_mpv_debug("^(INFO|METADATA)_.*=\\$.*");
+	#if 0
+	static QRegExp rx_subs2("^Sub:( >|) \\((\\d+)\\) '(.*)'");
+	static QRegExp rx_videoinfo("^\\[vd\\] VIDEO: .* (\\d+)x(\\d+) .* ([0-9.]+) fps"); // [vd] VIDEO:  624x352  25.000 fps  1018.5 kbps (127.3 kB/s)
+	#endif
+}
 
 void MPVProcess::parseLine(QByteArray ba) {
 	//qDebug() << "MPVProcess::parseLine:" << ba;
@@ -187,7 +185,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 		line.replace("[cplayer] ", "");
 		line.replace("[term-msg] ", "");
 
-		if (rx_mpv_debug.indexIn(line) > -1) {
+		if (rx_debug.indexIn(line) > -1) {
 			line = "[debug] " + line;
 		}
 	}
@@ -196,15 +194,15 @@ void MPVProcess::parseLine(QByteArray ba) {
 
 	// Parse A: V: line
 	//qDebug("MPVProcess::parseLine: %s", line.toUtf8().data());
-	if (rx_mpv_av.indexIn(line) > -1) {
+	if (rx_av.indexIn(line) > -1) {
 		#ifdef CUSTOM_STATUS
-		double sec = rx_mpv_av.cap(1).toDouble();
-		double length = rx_mpv_av.cap(2).toDouble();
-		bool paused = (rx_mpv_av.cap(3) == "yes");
-		bool buffering = (rx_mpv_av.cap(4) == "yes");
-		bool idle = (rx_mpv_av.cap(5) == "yes");
-		int video_bitrate = rx_mpv_av.cap(6).toInt();
-		int audio_bitrate = rx_mpv_av.cap(7).toInt();
+		double sec = rx_av.cap(1).toDouble();
+		double length = rx_av.cap(2).toDouble();
+		bool paused = (rx_av.cap(3) == "yes");
+		bool buffering = (rx_av.cap(4) == "yes");
+		bool idle = (rx_av.cap(5) == "yes");
+		int video_bitrate = rx_av.cap(6).toInt();
+		int audio_bitrate = rx_av.cap(7).toInt();
 
 		if (length != md.duration) {
 			md.duration = length;
@@ -253,21 +251,21 @@ void MPVProcess::parseLine(QByteArray ba) {
 
 		#else
 
-		//qDebug() << rx_mpv_av.cap(1);
-		//qDebug() << rx_mpv_av.cap(2);
+		//qDebug() << rx_av.cap(1);
+		//qDebug() << rx_av.cap(2);
 
-		QString status = rx_mpv_av.cap(2).trimmed();
+		QString status = rx_av.cap(2).trimmed();
 
 		int i = 4;
-		int h = rx_mpv_av.cap(i++).toInt();
-		int m = rx_mpv_av.cap(i++).toInt();
-		int s = rx_mpv_av.cap(i++).toInt();
+		int h = rx_av.cap(i++).toInt();
+		int m = rx_av.cap(i++).toInt();
+		int s = rx_av.cap(i++).toInt();
 		//qDebug("%d:%d:%d", h, m, s);
 		double sec = h * 3600 + m * 60 + s;
 
-		h = rx_mpv_av.cap(i++).toInt();
-		m = rx_mpv_av.cap(i++).toInt();
-		s = rx_mpv_av.cap(i++).toInt();
+		h = rx_av.cap(i++).toInt();
+		m = rx_av.cap(i++).toInt();
+		s = rx_av.cap(i++).toInt();
 		double length = h * 3600 + m * 60 + s;
 		if (length != md.duration) {
 			md.duration = length;
@@ -337,7 +335,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 #endif
 
 		if (!notified_mplayer_is_running) {
-			qDebug("MPVProcess::parseLine: starting sec: %f", sec);
+			qDebug() << "MPVProcess::parseLine: starting sec:" << sec;
 
 			if (md.video_width == 0 || md.video_height == 0) {
 				md.novideo = true;
@@ -383,10 +381,10 @@ void MPVProcess::parseLine(QByteArray ba) {
 		emit lineAvailable(line);
 
 		// Parse other things
-		qDebug("MPVProcess::parseLine: '%s'", line.toUtf8().data() );
+		qDebug() << "MPVProcess::parseLine:" << line;
 
 		// End of file
-		if (rx_mpv_endoffile.indexIn(line) > -1)  {
+		if (rx_endoffile.indexIn(line) > -1)  {
 			qDebug("MVPProcess::parseLine: detected end of file");
 			if (!received_end_of_file) {
 				// In case of playing VCDs or DVDs, maybe the first title
@@ -404,34 +402,34 @@ void MPVProcess::parseLine(QByteArray ba) {
 		else
 
 		// Window resolution
-		if (rx_mpv_dsize.indexIn(line) > -1) {
-			int w = rx_mpv_dsize.cap(1).toInt();
-			int h = rx_mpv_dsize.cap(2).toInt();
+		if (rx_dsize.indexIn(line) > -1) {
+			int w = rx_dsize.cap(1).toInt();
+			int h = rx_dsize.cap(2).toInt();
 			emit receivedWindowResolution( w, h );
 		}
 		else
 	
 		// VO
-		if (rx_mpv_vo.indexIn(line) > -1) {
-			emit receivedVO( rx_mpv_vo.cap(1) );
+		if (rx_vo.indexIn(line) > -1) {
+			emit receivedVO( rx_vo.cap(1) );
 			// Ask for window resolution
 			writeToStdin("print_text INFO_VIDEO_DSIZE=${=dwidth}x${=dheight}");
 		}
 		else
 		
 		// AO
-		if (rx_mpv_ao.indexIn(line) > -1) {
-			emit receivedAO( rx_mpv_ao.cap(1) );
+		if (rx_ao.indexIn(line) > -1) {
+			emit receivedAO( rx_ao.cap(1) );
 		}
 		else
 
 
 		// Audio
-		if (rx_mpv_audio.indexIn(line) > -1) {
-			int ID = rx_mpv_audio.cap(1).toInt();
-			QString lang = rx_mpv_audio.cap(3);
-			QString title = rx_mpv_audio.cap(6);
-			qDebug("MPVProcess::parseLine: audio id: %d, lang: '%s', name: '%s'", ID, lang.toUtf8().constData(), title.toUtf8().constData());
+		if (rx_audio.indexIn(line) > -1) {
+			int ID = rx_audio.cap(1).toInt();
+			QString lang = rx_audio.cap(3);
+			QString title = rx_audio.cap(6);
+			qDebug() << "MPVProcess::parseLine: audio id:" << ID << "lang:" << lang << "name:" << title;
 
 			#if NOTIFY_AUDIO_CHANGES
 			updateAudioTrack(ID, title, lang);
@@ -445,20 +443,20 @@ void MPVProcess::parseLine(QByteArray ba) {
 		}
 		else
 
-		if (rx_mpv_stream_title.indexIn(line) > -1) {
-			QString s = rx_mpv_stream_title.cap(1);
-			qDebug("MPVProcess::parseLine: stream_title: '%s'", s.toUtf8().data());
+		if (rx_stream_title.indexIn(line) > -1) {
+			QString s = rx_stream_title.cap(1);
+			qDebug() << "MPVProcess::parseLine: stream_title:" << s;
 			md.stream_title = s;
 			emit receivedStreamTitle(s);
 		}
 		else
 
 		// Subtitles
-		if (rx_mpv_subs.indexIn(line) > -1) {
-			int ID = rx_mpv_subs.cap(1).toInt();
-			QString lang = rx_mpv_subs.cap(3);
-			QString title = rx_mpv_subs.cap(6);
-			qDebug("MPVProcess::parseLine: sub id: %d, lang: '%s', name: '%s'", ID, lang.toUtf8().constData(), title.toUtf8().constData());
+		if (rx_subs.indexIn(line) > -1) {
+			int ID = rx_subs.cap(1).toInt();
+			QString lang = rx_subs.cap(3);
+			QString title = rx_subs.cap(6);
+			qDebug() << "MPVProcess::parseLine: sub id:" << ID << "lang:" << lang << "name:" << title;
 
 			#if NOTIFY_SUB_CHANGES
 			updateSubtitleTrack(ID, title, lang);
@@ -472,10 +470,10 @@ void MPVProcess::parseLine(QByteArray ba) {
 		}
 		else
 		#if 0
-		if (rx_mpv_subs2.indexIn(line) > -1) {
-			bool selected = (rx_mpv_subs2.cap(1) == " >");
-			int ID = rx_mpv_subs2.cap(2).toInt();
-			QString title = rx_mpv_subs2.cap(3);
+		if (rx_subs2.indexIn(line) > -1) {
+			bool selected = (rx_subs2.cap(1) == " >");
+			int ID = rx_subs2.cap(2).toInt();
+			QString title = rx_subs2.cap(3);
 			qDebug("MPVProcess::parseLine: sub id: %d title: '%s' selected: %d", ID, title.toUtf8().constData(), selected);
 			if (md.subs.find(SubData::Sub, ID) == -1) {
 				md.subs.add(SubData::Sub, ID);
@@ -487,9 +485,9 @@ void MPVProcess::parseLine(QByteArray ba) {
 
 #if !NOTIFY_VIDEO_CHANGES
 		// Video
-		if (rx_mpv_video.indexIn(line) > -1) {
-			int ID = rx_mpv_video.cap(1).toInt();
-			QString title = rx_mpv_video.cap(4);
+		if (rx_video.indexIn(line) > -1) {
+			int ID = rx_video.cap(1).toInt();
+			QString title = rx_video.cap(4);
 			qDebug("MPVProcess::parseLine: video id: %d, name: '%s'", ID, title.toUtf8().constData());
 			//md.videos.addID(ID);
 			md.videos.addName(ID, title);
@@ -499,19 +497,19 @@ void MPVProcess::parseLine(QByteArray ba) {
 
 #if 0
 		// Video info
-		if (rx_mpv_videoinfo.indexIn(line) > -1) {
-			md.video_width = rx_mpv_videoinfo.cap(1).toInt();
-			md.video_height = rx_mpv_videoinfo.cap(2).toInt();
-			md.video_fps = rx_mpv_videoinfo.cap(3);
+		if (rx_videoinfo.indexIn(line) > -1) {
+			md.video_width = rx_videoinfo.cap(1).toInt();
+			md.video_height = rx_videoinfo.cap(2).toInt();
+			md.video_fps = rx_videoinfo.cap(3);
 			qDebug("MPVProcess::parseLine: width: %d height: %d fps: %s", md.video_width, md.video_height, md.video_fps.toUtf8().constData());
 		}
 		else
 #endif
 
 		// Chapters
-		if (rx_mpv_chaptername.indexIn(line) > -1) {
-			int ID = rx_mpv_chaptername.cap(1).toInt();
-			QString title = rx_mpv_chaptername.cap(2);
+		if (rx_chaptername.indexIn(line) > -1) {
+			int ID = rx_chaptername.cap(1).toInt();
+			QString title = rx_chaptername.cap(2);
 			if (title.isEmpty()) title = QString::number(ID + 1);
 			#if NOTIFY_CHAPTER_CHANGES
 			chapters.addName(ID, title);
@@ -519,21 +517,20 @@ void MPVProcess::parseLine(QByteArray ba) {
 			#else
 			md.chapters.addName(ID, title);
 			#endif
-			qDebug("MPVProcess::parseLine: chapter id: %d title: %s", ID, title.toUtf8().constData());
+			qDebug() << "MPVProcess::parseLine: chapter id:" << ID << "title:" << title;
 			//md.chapters.list();
 		}
 		else
 
 #if NOTIFY_VIDEO_CHANGES || NOTIFY_AUDIO_CHANGES || NOTIFY_SUB_CHANGES
 		// Track info
-		if (rx_mpv_trackinfo.indexIn(line) > -1) {
-			int ID = rx_mpv_trackinfo.cap(3).toInt();
-			QString type = rx_mpv_trackinfo.cap(2);
-			QString name = rx_mpv_trackinfo.cap(5);
-			QString lang = rx_mpv_trackinfo.cap(4);
-			QString selected = rx_mpv_trackinfo.cap(6);
-			qDebug("MPVProcess::parseLine: ID: %d type: %s name: %s lang: %s selected: %s", ID, type.toUtf8().constData(), 
-				name.toUtf8().constData(), lang.toUtf8().constData(), selected.toUtf8().constData());
+		if (rx_trackinfo.indexIn(line) > -1) {
+			int ID = rx_trackinfo.cap(3).toInt();
+			QString type = rx_trackinfo.cap(2);
+			QString name = rx_trackinfo.cap(5);
+			QString lang = rx_trackinfo.cap(4);
+			QString selected = rx_trackinfo.cap(6);
+			qDebug() << "MPVProcess::parseLine: ID:" << ID << "type:" << type << "name:" << name << "lang:" << lang << "selected:" << selected;
 			/*
 			if (lang == "(unavailable)") lang = "";
 			if (name == "(unavailable)") name = "";
@@ -575,8 +572,8 @@ void MPVProcess::parseLine(QByteArray ba) {
 #endif
 
 #if DVDNAV_SUPPORT
-		if (rx_mpv_switch_title.indexIn(line) > -1) {
-			int title = rx_mpv_switch_title.cap(1).toInt();
+		if (rx_switch_title.indexIn(line) > -1) {
+			int title = rx_switch_title.cap(1).toInt();
 			qDebug("MPVProcess::parseLine: title changed to %d", title);
 			// Ask for track info
 			// Wait 10 secs. because it can take a while until the title start to play
@@ -586,31 +583,31 @@ void MPVProcess::parseLine(QByteArray ba) {
 #endif
 
 		//Playing
-		if (rx_mpv_playing.indexIn(line) > -1) {
+		if (rx_playing.indexIn(line) > -1) {
 			emit receivedPlaying();
 		}
 		else
 
-		if (rx_mpv_videocodec.indexIn(line) > -1) {
-			md.video_codec = rx_mpv_videocodec.cap(2);
-			qDebug("MPVProcess::parseLine: md.video_codec '%s'", md.video_codec.toUtf8().constData());
+		if (rx_videocodec.indexIn(line) > -1) {
+			md.video_codec = rx_videocodec.cap(1);
+			qDebug() << "MPVProcess::parseLine: md.video_codec:" << md.video_codec;
 		}
 		else
-		if (rx_mpv_audiocodec.indexIn(line) > -1) {
-			md.audio_codec = rx_mpv_audiocodec.cap(2);
-			qDebug("MPVProcess::parseLine: md.audio_codec '%s'", md.audio_codec.toUtf8().constData());
+		if (rx_audiocodec.indexIn(line) > -1) {
+			md.audio_codec = rx_audiocodec.cap(1);
+			qDebug() << "MPVProcess::parseLine: md.audio_codec:" << md.audio_codec;
 		}
 		else
 
-		if (rx_mpv_forbidden.indexIn(line) > -1) {
+		if (rx_forbidden.indexIn(line) > -1) {
 			qDebug("MVPProcess::parseLine: 403 forbidden");
 			emit receivedForbiddenText();
 		}
 
 		//Generic things
-		if (rx_mpv_generic.indexIn(line) > -1) {
-			tag = rx_mpv_generic.cap(1);
-			value = rx_mpv_generic.cap(2);
+		if (rx_generic.indexIn(line) > -1) {
+			tag = rx_generic.cap(1);
+			value = rx_generic.cap(2);
 			//qDebug("MPVProcess::parseLine: tag: %s", tag.toUtf8().constData());
 			//qDebug("MPVProcess::parseLine: value: %s", value.toUtf8().constData());
 
@@ -630,7 +627,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 					// I hope width & height are already set.
 					md.video_aspect = (double) md.video_width / md.video_height;
 				}
-				qDebug("MPVProcess::parseLine: md.video_aspect set to %f", md.video_aspect);
+				qDebug() << "MPVProcess::parseLine: md.video_aspect set to" << md.video_aspect;
 			}
 			if (tag == "INFO_VIDEO_BITRATE") {
 				int bitrate = value.toInt();
@@ -639,7 +636,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 			else
 			if (tag == "INFO_LENGTH") {
 				md.duration = value.toDouble();
-				qDebug("MPVProcess::parseLine: md.duration set to %f", md.duration);
+				qDebug() << "MPVProcess::parseLine: md.duration set to" << md.duration;
 			}
 			else
 			if (tag == "INFO_DEMUXER") {
