@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,10 +29,12 @@
 
 #define PLAYLIST_DOWNLOAD
 //#define PLAYLIST_DOUBLE_TOOLBAR
+#define PLAYLIST_DELETE_FROM_DISK
 
 class PLItem : public QStandardItem {
 public:
-	 enum PLItem_Roles { Role_Played = Qt::UserRole + 2, Role_Current = Qt::UserRole + 3 };
+	 enum PLItem_Roles { Role_Played = Qt::UserRole + 2, Role_Current = Qt::UserRole + 3, Role_Params = Qt::UserRole + 4,
+                         Role_Video_URL = Qt::UserRole + 5, Role_Icon_URL = Qt::UserRole + 6 };
 
 	PLItem();
 	PLItem(const QString filename, const QString name, double duration);
@@ -41,6 +43,9 @@ public:
 	void setFilename(const QString filename);
 	void setName(const QString name);
 	void setDuration(double duration);
+	void setExtraParams(const QStringList & pars);
+	void setVideoURL(const QString & url);
+	void setIconURL(const QString & url);
 	void setPlayed(bool played);
 	void setPosition(int position);
 	void setCurrent(bool b);
@@ -48,6 +53,9 @@ public:
 	QString filename();
 	QString name();
 	double duration();
+	QStringList extraParams();
+	QString videoURL();
+	QString iconURL();
 	bool played();
 	int position();
 	bool isCurrent();
@@ -106,7 +114,8 @@ public:
 	*/
 
 public slots:
-	void addItem(QString filename, QString name, double duration);
+	void addItem(QString filename, QString name, double duration, QStringList params = QStringList(),
+                 QString video_url = QString::null, QString icon_url = QString::null);
 
 	// Start playing, from item 0 if shuffle is off, or from
 	// a random item otherwise
@@ -117,6 +126,8 @@ public slots:
 	void playNext();
 	void playPrev();
 
+	void playNextAuto(); // Called from GUI when a file finished
+
 	void resumePlay();
 
 	void removeSelected();
@@ -136,11 +147,15 @@ public slots:
 	// Adds a directory, maybe with recursion (depends on user config)
 	void addDirectory(QString dir);
 
+#ifdef PLAYLIST_DELETE_FROM_DISK
 	void deleteSelectedFileFromDisk();
+#endif
 
 	bool maybeSave();
 	void load();
-	bool save();
+
+	bool saveCurrentPlaylist();
+	bool save(const QString & filename = QString::null);
 
 #ifdef PLAYLIST_DOWNLOAD
 	void openUrl();
@@ -172,20 +187,33 @@ public:
 	void setSavePlaylistOnExit(bool b) { save_playlist_in_config = b; };
 	void setPlayFilesFromStart(bool b) { play_files_from_start = b; };
 	void setIgnorePlayerErrors(bool b) { ignore_player_errors = b; };
+	void setStartPlayOnLoad(bool b) { start_play_on_load = b; };
 	void setAutomaticallyPlayNext(bool b) { automatically_play_next = b; };
+	void setAutoSort(bool b);
+	void setSortCaseSensitive(bool b);
+	void setFilterCaseSensitive(bool b);
 
 	bool directoryRecursion() { return recursive_add_directory; };
 	bool autoGetInfo() { return automatically_get_info; };
 	bool savePlaylistOnExit() { return save_playlist_in_config; };
 	bool playFilesFromStart() { return play_files_from_start; };
 	bool ignorePlayerErrors() { return ignore_player_errors; };
+	bool startPlayOnLoad() { return start_play_on_load; };
 	bool automaticallyPlayNext() { return automatically_play_next; };
+	bool autoSort();
+	bool sortCaseSensitive();
+	bool filterCaseSensitive();
 
 #ifdef PLAYLIST_DOWNLOAD
 	void setMaxItemsUrlHistory(int max_items);
 	int maxItemsUrlHistory();
 #endif
 
+#ifdef PLAYLIST_DELETE_FROM_DISK
+	void allowDeleteFromDisk(bool enabled) { allow_delete_from_disk = enabled; };
+	bool isDeleteFromDiskAllowed() { return allow_delete_from_disk; };
+#endif
+
 /*
 public:
 	MyAction * playPrevAct() { return prevAct; };
@@ -194,10 +222,13 @@ public:
 
 signals:
 	void requestToPlayFile(const QString & filename, int seek = -1);
+	void requestToPlayStream(const QString & filename, QStringList params = QStringList());
+
 	void requestToAddCurrentFile();
 	void playlistEnded();
 	void visibilityChanged(bool visible);
 	void modifiedChanged(bool);
+	void windowTitleChanged(const QString & title);
 
 protected:
 	void setCurrentItem(int current);
@@ -206,6 +237,11 @@ protected:
 	int chooseRandomItem();
 	QString lastDir();
 
+	void setPlaylistFilename(const QString &);
+	QString playlistFilename() { return playlist_filename; };
+
+	void updateWindowTitle();
+
 protected slots:
 	void playCurrent();
 	void itemActivated(const QModelIndex & index );
@@ -215,6 +251,15 @@ protected slots:
 	void editCurrentItem();
 	void editItem(int row);
 
+	void copyURL();
+	void openFolder();
+
+#ifdef CHROMECAST_SUPPORT
+	void playOnChromecast();
+#else
+	void openURLInWeb();
+#endif
+
 	void saveSettings();
 	void loadSettings();
 
@@ -249,8 +294,10 @@ protected:
 
 protected:
 	QString playlist_path;
+	QString playlist_filename;
 	QString latest_dir;
 
+	QMenu * file_menu;
 	QMenu * add_menu;
 	QMenu * remove_menu;
 	QMenu * popup;
@@ -263,6 +310,8 @@ protected:
 #ifdef PLAYLIST_DOUBLE_TOOLBAR
 	QToolBar * toolbar2;
 #endif
+
+	QToolButton * file_button;
 	QToolButton * add_button;
 	QToolButton * remove_button;
 
@@ -273,6 +322,7 @@ protected:
 	MyAction * openUrlAct;
 #endif
 	MyAction * saveAct;
+	MyAction * saveAsAct;
 	MyAction * playAct;
 	MyAction * prevAct;
 	MyAction * nextAct;
@@ -292,7 +342,18 @@ protected:
 	MyAction * removeSelectedAct;
 	MyAction * removeAllAct;
 
+#ifdef PLAYLIST_DELETE_FROM_DISK
 	MyAction * deleteSelectedFileFromDiskAct;
+#endif
+
+	MyAction * copyURLAct;
+	MyAction * openFolderAct;
+
+#ifdef CHROMECAST_SUPPORT
+	MyAction * playOnChromecastAct;
+#else
+	MyAction * openURLInWebAct;
+#endif
 
 	MyAction * showPositionColumnAct;
 	MyAction * showNameColumnAct;
@@ -319,10 +380,15 @@ private:
 	bool play_files_from_start;
 	int row_spacing;
 
+	bool start_play_on_load;
 	bool automatically_play_next;
 	bool ignore_player_errors;
 	bool change_name;
 	bool save_dirs;
+
+#ifdef PLAYLIST_DELETE_FROM_DISK
+	bool allow_delete_from_disk;
+#endif
 };
 
 #endif
