@@ -80,8 +80,10 @@ void Preferences::reset() {
 #endif
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-	//mplayer_bin= "mplayer/mplayer.exe";
 	mplayer_bin= "mpv/mpv.exe";
+	if (QSysInfo::WindowsVersion < QSysInfo::WV_VISTA) {
+		mplayer_bin= "mplayer/mplayer.exe";
+	}
 #else
 	//mplayer_bin = "mplayer";
 	mplayer_bin = "mpv";
@@ -146,6 +148,7 @@ void Preferences::reset() {
 	vdpau.ffwmv3vdpau = true;
 	vdpau.ffvc1vdpau = true;
 	vdpau.ffodivxvdpau = false;
+	vdpau.ffhevcvdpau = false;
 	vdpau.disable_video_filters = true;
 #endif
 
@@ -179,6 +182,9 @@ void Preferences::reset() {
 	osd_scale = 1;
 	subfont_osd_scale = 3;
 	osd_delay = 2200;
+#ifdef MPV_SUPPORT
+	osd_fractions = false;
+#endif
 
 	file_settings_method = "hash"; // Possible values: normal & hash
 
@@ -688,6 +694,7 @@ void Preferences::save() {
 	set->setValue("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau);
 	set->setValue("vdpau_ffvc1vdpau", vdpau.ffvc1vdpau);
 	set->setValue("vdpau_ffodivxvdpau", vdpau.ffodivxvdpau);
+	set->setValue("vdpau_ffhevcvdpau", vdpau.ffhevcvdpau);
 	set->setValue("vdpau_disable_video_filters", vdpau.disable_video_filters);
 #endif
 
@@ -717,6 +724,9 @@ void Preferences::save() {
 	set->setValue("osd_scale", osd_scale);
 	set->setValue("subfont_osd_scale", subfont_osd_scale);
 	set->setValue("osd_delay", osd_delay);
+#ifdef MPV_SUPPORT
+	set->setValue("osd_fractions", osd_fractions);
+#endif
 
 	set->setValue("file_settings_method", file_settings_method);
 
@@ -1255,6 +1265,7 @@ void Preferences::load() {
 	vdpau.ffwmv3vdpau = set->value("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau).toBool();
 	vdpau.ffvc1vdpau = set->value("vdpau_ffvc1vdpau", vdpau.ffvc1vdpau).toBool();
 	vdpau.ffodivxvdpau = set->value("vdpau_ffodivxvdpau", vdpau.ffodivxvdpau).toBool();
+	vdpau.ffhevcvdpau = set->value("vdpau_ffhevcvdpau", vdpau.ffhevcvdpau).toBool();
 	vdpau.disable_video_filters = set->value("vdpau_disable_video_filters", vdpau.disable_video_filters).toBool();
 #endif
 
@@ -1284,6 +1295,9 @@ void Preferences::load() {
 	osd_scale = set->value("osd_scale", osd_scale).toDouble();
 	subfont_osd_scale = set->value("subfont_osd_scale", subfont_osd_scale).toDouble();
 	osd_delay = set->value("osd_delay", osd_delay).toInt();
+#ifdef MPV_SUPPORT
+	osd_fractions = set->value("osd_fractions", osd_fractions).toBool();
+#endif
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
 
